#
# spec file for package macchina
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           macchina
Version:        6.1.6
Release:        1.4
Summary:        Fast, minimal and customizable system information frontend
License:        MIT
Group:          Productivity/Text/Utilities
URL:            https://github.com/Macchina-CLI/macchina#macchina
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
Source2:        cargo_config
BuildRequires:  cargo-packaging
Recommends:     wmctrl
ExcludeArch:    armv7l
ExcludeArch:    i586

%description
macchina lets you view system information, like your kernel version, uptime, memory usage, processor load and much more

%prep
%setup -q
%setup -qa1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
%{cargo_build}
strip target/release/%{name}

%install
%{cargo_install}
mkdir -p %{buildroot}%{_datadir}/%{name}
install -m0644 -t %{buildroot}%{_datadir}/%{name} %{name}.toml

%check
%ifarch "x86_64"
%{cargo_test}
%else
true # Skipping tests on other archs than x86_64 due to SIGSEGV on arm64
%endif

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_datadir}/%{name}/%{name}.toml
%{_bindir}/%{name}
%{_datadir}/%{name}

%changelog
* Tue Oct 11 2022 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 6.1.6:
  * libmacchina has been bumped to v6.3.1 which:
    Fixes a bug that causes framerate to appear as nil on certain macOS systems (Author: @123marvin123)
    Implement backlight readout for macOS (Author: @123marvin123)
  * update of vendored dependencies
  * Fixed --version not displaying the version (Author: @123marvin123
  * Fixed an issue that caused installations through cargo to fail due to a malformed lockfile.
  * Removed --export-config flag
  * Renamed CHANGELOG.txt to CHANGELOG.md
* Mon Jun 20 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue May 24 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue Apr  5 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Mon Mar 14 2022 william.brown@suse.com
- Update to resolve bsc#1196972 CVE-2022-24713 - Regex DOS
* Fri Mar  4 2022 Nicolas FORMICHELLA <stigpro@outlook.fr>
- Fix specfile due to upstream file placement change
* Fri Mar  4 2022 stigpro@outlook.fr
- Update to version 6.0.6~git0.c21ce78:
  * build: update lockfile
  * docs: update the changelog
  * build: bump to v6.0.6
  * docs: update CONTRIBUTING.md
  * legal: bump LICENSE year
  * docs: tweaks
  * docs: move from asciidoctor to scdoc
  * fix: incorrect target_os for a cfg flag
  * fix: change cfg's target_os
  * fix: properly read config from fallback
* Sat Dec 25 2021 stigpro@outlook.fr
- Update to version 6.0.1~git0.1e7fff0:
  * fix(docs): use correct manpage section numbering
  * docs: add matrix badge
  * chore: bump vergen to latest
  * chore(cli): derive Default for Opt
  * docs: update README benchmarks
  * docs: update documentation as a preparation for v6's release. (#237)
  * chore: bring back `export-config` flag (#236)
  * chore: bump libmacchina to v4.0.2
  * chore: freeze color-to-tui at v0.1.3
  * docs: update README
  * Fix the change of path of the config file
* Thu Nov 11 2021 stigpro@outlook.fr
- Update to version 5.0.4~git0.72b9c2b:
  * remove a change that doesn't apply yet
  * Fix compilation error upon cargo installation (closes #216)
  * Add Packaging status (#215)
  * docs: macchina should be lowercase
  * docs: update preview image
  * [DOC] Add zypper instructions for openSUSE Tumbleweed (#197)
  * slight changes to README
  * slight changes to README (and reference docs in themes)
  * update macchina.toml
  * typo
* Fri Nov  5 2021 Nicolas FORMICHELLA <stigpro@outlook.fr>
- Prevent test suite to run outside of `x86_64` because of repeated `SIGSEGV` on `arm64`
* Thu Nov  4 2021 Nicolas FORMICHELLA <stigpro@outlook.fr>
- Initial packaging for v5.0.3
